/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 *  Copyright (C) 2005 Takuro Ashie
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __SCIM_TOMOE_PREFS_H__
#define __SCIM_TOMOE_PREFS_H__

#define SCIM_TOMOE_CONFIG_USE_AUTO_FIND           "/Helper/Tomoe/UseAutoFind"
#define SCIM_TOMOE_CONFIG_AUTO_FIND_TIME          "/Helper/Tomoe/AutoFindTime"
#define SCIM_TOMOE_CONFIG_CLEAR_ON_SELECT         "/Helper/Tomoe/ClearOnSelect"
#define SCIM_TOMOE_CONFIG_WINDOW_ALWAYS_TOP       "/Helper/Tomoe/AlwaysTop"

#define SCIM_TOMOE_CONFIG_USE_AUTO_FIND_DEFAULT     true
#define SCIM_TOMOE_CONFIG_AUTO_FIND_TIME_DEFAULT    0
#define SCIM_TOMOE_CONFIG_CLEAR_ON_SELECT_DEFAULT   false
#define SCIM_TOMOE_CONFIG_WINDOW_ALWAYS_TOP_DEFAULT false

#endif /* __SCIM_TOMOE_PREFS_H__ */
